==> bagaar-bagaaravel-2.1.3-74115b.zip: src/Commands/BagaaravelModelGenerator.php <==
<?php

namespace Bagaaravel\Commands;

use Illuminate\Console\Command;
use Illuminate\Database\Eloquent\Relations\Relation;
use Illuminate\Filesystem\Filesystem;
use \Illuminate\Console\AppNamespaceDetectorTrait;
use Illuminate\Support\Str;

class BagaaravelModelGenerator extends Command
{
    use AppNamespaceDetectorTrait;

    protected $signature = 'bagaar:model {name : The Model name}';
    protected $description = 'Generate Models';
    private $filesystem;
    private $namespace;
    private $modelName;

    public function __construct(Filesystem $filesystem)
    {
        // $article = new \App\Models\ . ucfirst($name). ();
        // $ref = new \ReflectionObject($article);
        // $methods = $ref->getMethods(\ReflectionMethod::IS_PUBLIC);
        // $methods = array_filter($methods, function ($method) {
        //     return $method->class === 'App\Models\Article';
        // });
        // $relations = [];
        // foreach ($methods as $method) {
        //     $result = $article->{$method->name}();
        //     if ($result instanceof Relation) {
        //         $relations[] = $method->name;
        //     }
        // }
        // $this->filesystem = $filesystem;
        parent::__construct();
    }

    public function handle()
    {
        // $this->modelName = ucfirst(trim($this->input->getArgument('name')));
        // $this->namespace = $this->getAppNamespace();
        // $path = '';
        // if (Str::contains($this->modelName, '/')) {
        //     $parts = explode('/', $this->modelName);
        //     $this->namespace .= $parts[0];
        //     $path = $parts[0] . '/';
        //     $this->modelName = $parts[1];
        // } else {
        //     $this->namespace = rtrim($this->namespace, '\\');
        // }
        // $template = $this->filesystem->get(__DIR__ . '/../Templates/Model.tpl');
        // $template = str_replace(
        //     ['%MODEL%', '%NAMESPACE%'],
        //     [$this->modelName, $this->namespace],
        //     $template
        // );
        // $filePath = app_path($path . $this->modelName . '.php');
        // if ($this->filesystem->exists($filePath)) {
        //     $this->warn('File already exists!');
        //     exit(1);
        // }
        // $this->filesystem->put($filePath, $template);
        $this->info('WIP, check back later');
    }
}

==> bagaar-bagaaravel-2.3.1-931556.zip: src/Commands/BagaaravelModelGenerator.php <==
<?php

namespace Bagaaravel\Commands;

use Illuminate\Console\Command;
use Illuminate\Database\Eloquent\Relations\Relation;
use Illuminate\Filesystem\Filesystem;
use Illuminate\Support\Str;

class BagaaravelModelGenerator extends Command
{
    protected $signature = 'bagaar:model {name : The Model name}';
    protected $description = 'Generate Models';
    private $filesystem;
    private $namespace;
    private $modelName;

    public function __construct(Filesystem $filesystem)
    {
        // $article = new \App\Models\ . ucfirst($name). ();
        // $ref = new \ReflectionObject($article);
        // $methods = $ref->getMethods(\ReflectionMethod::IS_PUBLIC);
        // $methods = array_filter($methods, function ($method) {
        //     return $method->class === 'App\Models\Article';
        // });
        // $relations = [];
        // foreach ($methods as $method) {
        //     $result = $article->{$method->name}();
        //     if ($result instanceof Relation) {
        //         $relations[] = $method->name;
        //     }
        // }
        // $this->filesystem = $filesystem;
        parent::__construct();
    }

    public function handle()
    {
        // $this->modelName = ucfirst(trim($this->input->getArgument('name')));
        // $this->namespace = $this->getAppNamespace();
        // $path = '';
        // if (Str::contains($this->modelName, '/')) {
        //     $parts = explode('/', $this->modelName);
        //     $this->namespace .= $parts[0];
        //     $path = $parts[0] . '/';
        //     $this->modelName = $parts[1];
        // } else {
        //     $this->namespace = rtrim($this->namespace, '\\');
        // }
        // $template = $this->filesystem->get(__DIR__ . '/../Templates/Model.tpl');
        // $template = str_replace(
        //     ['%MODEL%', '%NAMESPACE%'],
        //     [$this->modelName, $this->namespace],
        //     $template
        // );
        // $filePath = app_path($path . $this->modelName . '.php');
        // if ($this->filesystem->exists($filePath)) {
        //     $this->warn('File already exists!');
        //     exit(1);
        // }
        // $this->filesystem->put($filePath, $template);
        $this->info('WIP, check back later');
    }

    protected function getAppNamespace()
    {
        return \Illuminate\Container\Container::getInstance()->getNamespace();
    }
}
